@@ -1,6 +1,10 @@
 #ifndef _ARRANGEMENTS_H_
 #define _ARRANGEMENTS_H_ 1
 
+#define R_NO_REMAP
+#include <R.h>
+#include <Rinternals.h>
+
 SEXP next_combinations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEXP _type);
 
 SEXP next_asc_k_partitions(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP _type);
@@ -11,12 +15,14 @@ SEXP npart_k(SEXP _n, SEXP _k);
 
 SEXP npart_k_bigz(SEXP _n, SEXP _k);
 
-SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEXP freq, SEXP _type);
+SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEXP _type);
 
 SEXP nperm_k(SEXP _n, SEXP _k);
 
 SEXP nperm_k_bigz(SEXP _n, SEXP _k);
 
+SEXP next_multiset_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEXP freq, SEXP _type);
+
 SEXP nperm_f(SEXP freq, SEXP _k);
 
 SEXP nperm_f_bigz(SEXP freq, SEXP _k);
