@@ -3,12 +3,12 @@
 #include <Rinternals.h>
 #include <gmp.h>
 #include "arrangements.h"
-#include "algorithms/k_permutation.h"
+#include "next/k_permutation.h"
 #include "utils.h"
 
 double npermutations_f(int* freq, size_t flen, size_t k);
 
-SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEXP freq, SEXP _type) {
+SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEXP _type) {
     size_t i, j, h;
 
     size_t n = as_uint(_n);
@@ -16,11 +16,7 @@ SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEX
     int d;
     double dd;
     if (Rf_asInteger(_d) == -1) {
-        if (freq == R_NilValue) {
-            dd = fallfact(n, k);
-        } else {
-            dd = npermutations_f(INTEGER(freq), Rf_length(freq), k);
-        }
+        dd = fallfact(n, k);
     } else {
         dd = as_uint(_d);
     }
@@ -46,41 +42,42 @@ SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEX
     }
     d = round(dd);
 
-    SEXP as;
+    SEXP as, cycles;
     unsigned int* ap;
+    unsigned int* cyclep;
     int nprotect = 0;
 
     int status = 0;
 
     if (state == R_NilValue) {
         as = R_UnboundValue;
+        cycles = R_UnboundValue;
     } else {
         as = Rf_findVarInFrame(state, Rf_install("a"));
+        cycles = Rf_findVarInFrame(state, Rf_install("cycle"));
     }
 
     if (as == R_UnboundValue) {
         if (state == R_NilValue) {
             ap = (unsigned int*) R_alloc(n, sizeof(int));
+            cyclep = (unsigned int*) R_alloc(k, sizeof(int));
         } else {
             as = PROTECT(Rf_allocVector(INTSXP, n));
             Rf_defineVar(Rf_install("a"), as, state);
             UNPROTECT(1);
             ap = (unsigned int*) INTEGER(as);
+
+            cycles = PROTECT(Rf_allocVector(INTSXP, k));
+            Rf_defineVar(Rf_install("cycle"), cycles, state);
+            UNPROTECT(1);
+            cyclep = (unsigned int*) INTEGER(cycles);
         }
-        if (freq == R_NilValue) {
-            for(i=0; i<n; i++) ap[i] = i;
-        } else {
-            fp = INTEGER(freq);
-            h = 0;
-            for (i = 0; i< Rf_length(freq); i++) {
-                for (j = 0; j< fp[i]; j++) {
-                    ap[h++] = i;
-                }
-            }
-        }
+        for(i=0; i<n; i++) ap[i] = i;
+        for(i=0; i<k; i++) cyclep[i] = n - i;
 
     } else {
         ap = (unsigned int*) INTEGER(as);
+        cyclep = (unsigned int*) INTEGER(cycles);
         status = 1;
     }
 
@@ -108,7 +105,7 @@ SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEX
 
         for (j=0; j<d; j++) {
             if (status) {
-                if (!next_k_permutation(ap, n, k)) {
+                if (!next_k_permutation(ap, cyclep, n, k)) {
                     status = 0;
                     break;
                 }
@@ -162,7 +159,7 @@ SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEX
 
         for (j=0; j<d; j++) {
             if (status) {
-                if (!next_k_permutation(ap, n, k)) {
+                if (!next_k_permutation(ap, cyclep, n, k)) {
                     status = 0;
                     break;
                 }
@@ -209,7 +206,7 @@ SEXP next_k_permutations(SEXP _n, SEXP _k, SEXP _d, SEXP state, SEXP labels, SEX
 
         for (j=0; j<d; j++) {
             if (status) {
-                if (!next_k_permutation(ap, n, k)) {
+                if (!next_k_permutation(ap, cyclep, n, k)) {
                     status = 0;
                     break;
                 }
@@ -284,144 +281,3 @@ SEXP nperm_k_bigz(SEXP _n, SEXP _k) {
     free(c);
     return out;
 }
-
-
-double npermutations_f(int* freq, size_t flen, size_t k) {
-    int n = 0;
-    int i, j, h;
-    for (i=0; i<flen; i++) n += freq[i];
-    if (k > n) {
-        return 0;
-    }
-
-    int maxf;
-    maxf = 0;
-    for (i=0; i<flen; i++) {
-        if (freq[i] > maxf) maxf = freq[i];
-    }
-
-    double rfact = 1;
-    for (j=2; j<=k; j++) {
-        rfact = rfact*j;
-    }
-    size_t factlen = (k < maxf ? k : maxf) + 1;
-    double* fact = (double*) malloc(factlen * sizeof(double));
-    fact[0] = 1;
-    for (j=1; j< factlen; j++) fact[j] = j * fact[j-1];
-
-    double* p = (double*) malloc((k+1) * sizeof(double));
-    for (j=0; j<=k; j++) p[j] = 0;
-
-    double ptemp;
-
-    for (i=0; i<flen; i++) {
-        if (i == 0) {
-            for (j=0; j<=k && j<=freq[i]; j++) {
-                p[j] = rfact / fact[j];
-            }
-            ptemp = p[k];
-        } else if (i < flen - 1){
-            for (j=k; j>0; j--) {
-                ptemp = 0;
-                for(h=0; h<=freq[i] && h<=j; h++) {
-                    ptemp += p[j-h] / fact[h];
-                }
-                p[j] = ptemp;
-            }
-        } else {
-            ptemp = 0;
-            for(h=0; h<=freq[i] && h<=k; h++) {
-                ptemp += p[k-h] / fact[h];
-            }
-        }
-    }
-
-    free(fact);
-    free(p);
-    return ptemp;
-}
-
-SEXP nperm_f(SEXP freq, SEXP _k) {
-    int* fp = INTEGER(freq);
-    size_t flen = Rf_length(freq);
-    size_t k = as_uint(_k);
-    return Rf_ScalarReal(npermutations_f(fp, flen, k));
-}
-
-void npermutations_f_bigz(mpz_t z, int* freq, size_t flen, size_t k) {
-    int n = 0;
-    int i, j, h;
-    for (i=0; i<flen; i++) n += freq[i];
-    if (k > n) {
-        mpz_set(z, 0);
-        return;
-    }
-
-    int maxf;
-    maxf = 0;
-    for (i=0; i<flen; i++) {
-        if (freq[i] > maxf) maxf = freq[i];
-    }
-
-    mpz_t rfact;
-    mpz_init(rfact);
-    mpz_fac_ui(rfact, k);
-
-    size_t factlen = (k < maxf ? k : maxf) + 1;
-    mpz_t* fact = (mpz_t*) malloc(factlen * sizeof(mpz_t));
-    for (j=0; j< factlen; j++) mpz_init(fact[j]);
-
-    mpz_set_ui(fact[0], 1);
-    for (j=1; j< factlen; j++) mpz_mul_ui(fact[j], fact[j-1], j);
-
-    mpz_t* p = (mpz_t*) malloc((k+1) * sizeof(mpz_t));
-    for (j=0; j<=k; j++) mpz_init(p[j]);
-
-    mpz_t ptemp;
-    mpz_init(ptemp);
-
-    for (i=0; i<flen; i++) {
-        if (i == 0) {
-            for (j=0; j<=k && j<=freq[i]; j++) {
-                mpz_cdiv_q(p[j], rfact, fact[j]);
-            }
-            mpz_set(z, p[k]);
-        } else if (i < flen - 1){
-            for (j=k; j>0; j--) {
-                mpz_set_ui(z, 0);
-                for(h=0; h<=freq[i] && h<=j; h++) {
-                    mpz_cdiv_q(ptemp, p[j-h], fact[h]);
-                    mpz_add(z, z, ptemp);
-                }
-                mpz_set(p[j], z);
-            }
-        } else {
-            mpz_set_ui(z, 0);
-            for(h=0; h<=freq[i] && h<=k; h++) {
-                mpz_cdiv_q(ptemp, p[k-h], fact[h]);
-                mpz_add(z, z, ptemp);
-            }
-        }
-    }
-
-    for (j=0; j< factlen; j++) mpz_clear(fact[j]);
-    for (j=0; j<=k; j++) mpz_clear(p[j]);
-    free(fact);
-    free(p);
-    mpz_clear(rfact);
-    mpz_clear(ptemp);
-}
-
-SEXP nperm_f_bigz(SEXP freq, SEXP _k) {
-    int* fp = INTEGER(freq);
-    size_t flen = Rf_length(freq);
-    size_t k = as_uint(_k);
-    mpz_t z;
-    mpz_init(z);
-    npermutations_f_bigz(z, fp, flen, k);
-    char* c = mpz_get_str(NULL, 10, z);
-    SEXP out = Rf_mkString(c);
-    mpz_clear(z);
-    free(c);
-    return out;
-}
